@@ -19,11 +19,12 @@
 
 from aliyunsdkcore.request import RpcRequest
 from aliyunsdkcompanyreg.endpoint import endpoint_data
+import json
 
 class ListUserSolutionsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'companyreg', '2020-03-06', 'ListUserSolutions')
+		RpcRequest.__init__(self, 'companyreg', '2020-03-06', 'ListUserSolutions','companyreg')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -40,7 +41,7 @@ class ListUserSolutionsRequest(RpcRequest):
 		return self.get_query_params().get('ExistStatus')
 
 	def set_ExistStatus(self, ExistStatus):  # Array
-		pass
+		self.add_query_param("ExistStatus", json.dumps(ExistStatus))
 	def get_IntentionBizId(self): # String
 		return self.get_query_params().get('IntentionBizId')
 
