@@ -23,7 +23,7 @@ from aliyunsdkcompanyreg.endpoint import endpoint_data
 class StartBackToBackCallRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'companyreg', '2020-03-06', 'StartBackToBackCall')
+		RpcRequest.__init__(self, 'companyreg', '2020-03-06', 'StartBackToBackCall','companyreg')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -31,6 +31,16 @@ class StartBackToBackCallRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_CallCenterNumber(self): # String
+		return self.get_query_params().get('CallCenterNumber')
+
+	def set_CallCenterNumber(self, CallCenterNumber):  # String
+		self.add_query_param('CallCenterNumber', CallCenterNumber)
+	def get_MobileKey(self): # String
+		return self.get_query_params().get('MobileKey')
+
+	def set_MobileKey(self, MobileKey):  # String
+		self.add_query_param('MobileKey', MobileKey)
 	def get_BizType(self): # String
 		return self.get_query_params().get('BizType')
 
@@ -41,11 +51,6 @@ class StartBackToBackCallRequest(RpcRequest):
 
 	def set_Caller(self, Caller):  # String
 		self.add_query_param('Caller', Caller)
-	def get_CallCenterNumber(self): # String
-		return self.get_query_params().get('CallCenterNumber')
-
-	def set_CallCenterNumber(self, CallCenterNumber):  # String
-		self.add_query_param('CallCenterNumber', CallCenterNumber)
 	def get_SkillType(self): # Long
 		return self.get_query_params().get('SkillType')
 
